package com.qs.mp.web.controller.api.admin;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.admin.domain.param.UserExchangeOrderQueryParam;
import com.qs.mp.admin.domain.vo.UserExchangeOrderVO;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.user.domain.UserExchangeOrder;
import com.qs.mp.user.service.IUserExchangeOrderService;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Objects;

/**
 * 用户兑换订单管理相关API
 * @author Cup
 * @date 2022/5/10
 */
@Api(tags = "用户兑换订单管理相关API")
@RestController
@RequestMapping("/api/v1/mp/admin/exchange/order/*")
public class UserExchangeOrderMgrController extends BaseApiController {


    @Autowired
    private IUserExchangeOrderService userExchangeOrderService;

    @PostMapping("/list")
    @ApiOperation("用户兑换订单列表")
    public TableDataInfo list(@RequestBody UserExchangeOrderQueryParam userExchangeOrderQueryParam) {

        startPage();

        QueryWrapper<UserExchangeOrder> queryWrapper = new QueryWrapper<>();

        // 封装条件
        if (StringUtils.isNotBlank(userExchangeOrderQueryParam.getGoodsName())) {
            queryWrapper.like("t2.title", userExchangeOrderQueryParam.getGoodsName());
        }

        if (StringUtils.isNotBlank(userExchangeOrderQueryParam.getPhone())) {
            queryWrapper.eq("t4.phonenumber", userExchangeOrderQueryParam.getPhone());
        }

        if (Objects.nonNull(userExchangeOrderQueryParam.getMinExchangePrice()) && Objects.nonNull(userExchangeOrderQueryParam.getMaxExchangePrice())) {
            queryWrapper.between("t2.exchange_price", userExchangeOrderQueryParam.getMinExchangePrice(), userExchangeOrderQueryParam.getMaxExchangePrice());
        }

        if (Objects.nonNull(userExchangeOrderQueryParam.getStartTime()) && Objects.nonNull(userExchangeOrderQueryParam.getEndTime())) {
            queryWrapper.between("t1.created_time", userExchangeOrderQueryParam.getStartTime(), userExchangeOrderQueryParam.getEndTime());
        }

        queryWrapper.orderByDesc("t1.created_time");

        List<UserExchangeOrderVO> list =  userExchangeOrderService.listUserExchangeOrderByWrapper(queryWrapper);

        return getDataTable(list);
    }
}
